@@ -569,9 +569,13 @@ def test_shrink_1d():
 def test_rebin_1d():
     h = bh.Histogram(bh.axis.Regular(20, 1, 5))
     h.fill(1.1)
+
     hs = h[{0: slice(None, None, bh.rebin(4))}]
     assert_array_equal(hs.view(), [1, 0, 0, 0, 0])
 
+    hs = h[{0: bh.rebin(4)}]
+    assert_array_equal(hs.view(), [1, 0, 0, 0, 0])
+
 
 def test_shrink_rebin_1d():
     h = bh.Histogram(bh.axis.Regular(20, 0, 4))
@@ -594,6 +598,7 @@ def test_rebin_nd():
     assert h[{0: s[:: bh.rebin(2)], 2: s[:: bh.rebin(2)]}].axes.size == (10, 30, 20)
 
     assert h[{1: s[:: bh.sum]}].axes.size == (20, 40)
+    assert h[{1: bh.sum}].axes.size == (20, 40)
 
 
 # CLASSIC: This used to have metadata too, but that does not compare equal
@@ -667,16 +672,36 @@ def test_pickle_1():
     assert a == b
 
 
+def test_fill_bool_not_bool():
+    h = bh.Histogram(bh.axis.Boolean())
+
+    h.fill([0, 1, 1, 7, -3])
+
+    assert_array_equal(h.view(), [1, 4])
+
+
 def test_pick_bool():
-    a = bh.Histogram(bh.axis.Boolean(), bh.axis.Boolean(metadata={"one": 1}))
+    h = bh.Histogram(bh.axis.Boolean(), bh.axis.Boolean(metadata={"one": 1}))
 
-    a.fill([True, True, False, False], [True, False, True, True])
-    a.fill([True, True, True], True)
+    h.fill([True, True, False, False], [True, False, True, True])
+    h.fill([True, True, True], True)
 
-    assert_array_equal(a[True, :].view(), [1, 4])
-    assert_array_equal(a[False, :].view(), [0, 2])
-    assert_array_equal(a[:, False].view(), [0, 1])
-    assert_array_equal(a[:, True].view(), [2, 4])
+    assert_array_equal(h[True, :].view(), [1, 4])
+    assert_array_equal(h[False, :].view(), [0, 2])
+    assert_array_equal(h[:, False].view(), [0, 1])
+    assert_array_equal(h[:, True].view(), [2, 4])
+
+
+def test_slice_bool():
+    h = bh.Histogram(bh.axis.Boolean())
+    h.fill([0, 0, 0, 1, 3, 4, -2])
+
+    assert_array_equal(h.view(), [3, 4])
+    assert_array_equal(h[1:].view(), [4])
+    assert_array_equal(h[:1].view(), [3])
+
+    assert_array_equal(h[:1].axes[0].centers, [0.5])
+    assert_array_equal(h[1:].axes[0].centers, [1.5])
 
 
 def test_pickle_bool():
@@ -1078,3 +1103,86 @@ def test_shape():
 def test_empty_shape():
     h = bh.Histogram()
     assert h.shape == ()
+
+
+# issue #416 a
+def test_hist_division():
+    edges = [0, 0.25, 0.5, 0.75, 1, 2, 3, 4, 7, 10]
+    edges = [-x for x in reversed(edges)] + edges[1:]
+
+    h = bh.Histogram(bh.axis.Variable(edges))
+    h[...] = 1
+    h1 = h.copy()
+
+    dens = h.view().copy()
+    dens /= h.axes[0].widths * h.sum()
+
+    h1 /= h.axes[0].widths * h.sum()
+
+    assert_array_equal(h1.view(), dens)
+
+
+# issue #416 b
+# def test_hist_division():
+#     edges = [0, .25, .5, .75, 1, 2, 3, 4, 7, 10]
+#    edges = [-x for x in reversed(edges)] + edges[1:]
+#
+#    h = bh.Histogram(bh.axis.Variable(edges))
+#    h[...] = 1
+#
+#    dens = h.view().copy() / h.axes[0].widths * h.sum()
+#    h1 = h.copy()
+#
+#    h1[:] /=  h.axes[0].widths * h.sum()
+#
+#    assert_allclose(h1.view(), dens)
+
+
+def test_add_hists():
+    edges = [0, 0.25, 0.5, 0.75, 1, 2, 3, 4, 7, 10]
+    edges = [-x for x in reversed(edges)] + edges[1:]
+
+    h = bh.Histogram(bh.axis.Variable(edges))
+    h[...] = 1
+
+    h1 = h.copy()
+    h1 += h.view()
+
+    h2 = h.copy()
+    h2 += h1
+
+    h3 = h.copy()
+    h3 += 5
+
+    assert_array_equal(h, 1)
+    assert_array_equal(h1, 2)
+    assert_array_equal(h2, 3)
+    assert_array_equal(h3, 6)
+
+
+def test_add_broadcast():
+    h = bh.Histogram(bh.axis.Regular(10, 0, 1), bh.axis.Regular(20, 0, 1))
+
+    h1 = h.copy()
+    h2 = h.copy()
+
+    h1[...] = 1
+    assert h1.view().sum() == 10 * 20
+    assert h1.view(flow=True).sum() == 10 * 20
+
+    h2 = h + [[1]]
+    assert h2.sum() == 10 * 20
+    assert h2.sum(flow=True) == 10 * 20
+
+    h3 = h + np.ones((10, 20))
+    assert h3.sum() == 10 * 20
+    assert h3.sum(flow=True) == 10 * 20
+
+    h4 = h + np.ones((12, 22))
+    assert h4.view(flow=True).sum() == 12 * 22
+
+    h5 = h + np.ones((10, 1))
+    assert h5.sum(flow=True) == 10 * 20
+
+    h5 = h + np.ones((1, 22))
+    assert h5.sum(flow=True) == 12 * 22
